#
# spec file for package netpbm
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define debug_build    0
%define asan_build     0
%define libmaj  11
%define libmin  80
%define libver  %{libmaj}.%{libmin}
Name:           netpbm
Version:        10.80.1
Release:        lp151.4.3.1
Summary:        A Powerful Graphics Conversion Package
License:        BSD-3-Clause AND GPL-2.0+ AND IJG AND MIT AND SUSE-Public-Domain
Group:          Productivity/Graphics/Convertors
Url:            http://netpbm.sourceforge.net/
Source:         netpbm-%{version}-nohpcdtoppm-noppmtompeg.tar.bz2
Source1:        netpbm-%{version}-documentation.tar.bz2
Source2:        baselibs.conf
Source3:        prepare-src-tarball
# SUSE specific
Patch0:         %{name}-make.patch
# neccessary for running with ASAN
Patch1:         netpbm-asan.patch
Patch3:         %{name}-tmpfile.patch
Patch4:         %{name}-security-code.patch
Patch5:         %{name}-security-scripts.patch
Patch6:         %{name}-gcc-warnings.patch
Patch7:         makeman-py3.patch
Patch8:         netpbm-CVE-2018-8975.patch
# CVE-2017-2579 [bsc#1024288], CVE-2017-2580 [bsc#1024291]
Patch9:         netpbm-CVE-2017-2579,2580.patch
BuildRequires:  flex
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
# needed for the makeman
BuildRequires:  python3-base
BuildRequires:  pkgconfig(x11)
Provides:       pbmplus

%description
The latest version of the Portable Bitmap Plus Utilities. This large
package, which is by now available for all hardware platforms, provides
tools for graphics conversion. Using these tools, images can be
converted from virtually any format into any other format. A few of the
supported formats include: GIF, PC-Paintbrush, IFF ILBM, Gould Scanner
file, MTV ray tracer, Atari Degas .pi1 and .pi3, Macintosh PICT, HP
Paintjet file, QRT raytracer, AUTOCAD slide, Atari Spectrum (compressed
and uncompressed), Andrew Toolkit raster object, and many more. On top
of that, man pages are included for all tools.

%package vulnerable
Summary:        Utilities with (Potential) Security Issues
Group:          Productivity/Graphics/Convertors
Requires:       %{name} = %{version}

%description vulnerable
Provides utilities that have been shipped with main package along
others, but was considered vulnerable.

%package -n libnetpbm%{libmaj}
Summary:        Libraries for the NetPBM (NetPortableBitmap) Graphic Formats
Group:          System/Libraries
Provides:       libnetpbm = %{version}
Obsoletes:      libnetpbm < %{version}

%description -n libnetpbm%{libmaj}
These are the libs for the netpbm graphic formats. The tools can be
found in the netpbm package. The sources are contained in the netpbm
source package.

%package -n libnetpbm-devel
Summary:        Libraries for the NetPBM Graphic Formats - files mandatory for development
Group:          Development/Libraries/C and C++
Requires:       libnetpbm%{libmaj} = %{version}

%description -n libnetpbm-devel
These are the libs for the netpbm graphic formats. The tools can be
found in the netpbm package. The sources are contained in the netpbm
source package.

%prep
%setup -q -D -a 1
%patch0
%patch3
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
mkdir pnmtopalm # for %%doc pnmtopalm
cp -p converter/other/pnmtopalm/{LICENSE,README} pnmtopalm

%build
# netpbm has _interactive_ configure perl script
cp config.mk.in config.mk # recomended by upstream, see doc/INSTALL
sed -i "s:STATICLIB_TOO = y:STATICLIB_TOO = n:" config.mk
# following two added 10.66.0, reported upstream
# recipe for target 'converter/install.manweb' failed
echo 'install.manweb:' >> converter/ppm/hpcdtoppm/Makefile
# dtto for ppmtompeg
echo 'install.manweb:' >> converter/ppm/ppmtompeg/Makefile
export CFLAGS="%{optflags} -flax-vector-conversions"
%if %{debug_build}
export CFLAGS="$CFLAGS -O0"
%endif
%if %{asan_build}
export CFLAGS="$CFLAGS -fsanitize=address"
patch -p1 < %{PATCH1}
%endif
make %{?_smp_mflags} CFLAGS="$CFLAGS"
rm doc/INSTALL
#
# convert html to man pages
cd netpbm.sourceforge.net/doc
 ../../buildtools/makeman *.html
for i in 1 3 5 ; do
  mkdir -p ../../man/man${i}
  mv *.${i} ../../man/man${i}
done

%install
# netpbm has _interactive_ install perl script, see doc/INSTALL
make pkgdir=`pwd`/package package STRIPFLAG=
#
mkdir -p %{buildroot}%{_prefix}/{bin,include,%{_lib},share/man,share/%{name}}
cp -pd  package/bin/* 		%{buildroot}%{_bindir}
cp -pd  package/lib/*.so* 	%{buildroot}%{_libdir}
ln -s   libnetpbm.so.%{libver} 	%{buildroot}%{_libdir}/libnetpbm.so
cp -prd package/include/netpbm 	%{buildroot}%{_includedir}
cp -prd man/* 			%{buildroot}%{_mandir}
install -m 644 converter/other/pnmtopalm/*.map \
				%{buildroot}%{_datadir}/%{name}
rm %{buildroot}%{_bindir}/g3topbm # conflict with g3utils

%post   -n libnetpbm%{libmaj} -p /sbin/ldconfig
%postun -n libnetpbm%{libmaj} -p /sbin/ldconfig

%check
# do not run unneccesary tests
sed -i '/all-in-place/d'        test/Test-Order
sed -i '/legacy-names/d'        test/Test-Order
# picttoppm.c: #error "Unfixable. Don't ship me"
sed -i '/pict-roundtrip/d'      test/Test-Order
# do not build require ghostscript just to test vulnerable utility
sed -i '/^ps.*\.test/d'         test/Test-Order
# ignore failing tests for some architectures for now
%ifarch s390x
sed -i '/pbm-misc-converters/d' test/Test-Order
%endif
%ifarch s390x ppc64le aarch64
sed -i '/palm-roundtrip/d'      test/Test-Order
sed -i '/palm-roundtrip2/d'     test/Test-Order
%endif
mkdir package-test-{tmp,results}
make pkgdir=`pwd`/package tmpdir=`pwd`/package-test-tmp RESULTDIR=`pwd`/package-test-results check-package 

%files
%doc README doc/* netpbm.sourceforge.net/doc
%doc pnmtopalm/
%{_mandir}/man1/*%{ext_man}
%exclude %{_mandir}/man1/pstopnm.1%{ext_man}
%{_mandir}/man5/*%{ext_man}
%{_bindir}/*
%exclude %{_bindir}/pstopnm
%{_datadir}/%{name}

%files vulnerable
%{_bindir}/pstopnm
%{_mandir}/man1/pstopnm.1%{ext_man}

%files -n libnetpbm%{libmaj}
%{_libdir}/lib*.so.%{libmaj}
%{_libdir}/lib*.so.%{libver}

%files -n libnetpbm-devel
%{_includedir}/%{name}
%{_libdir}/lib*.so
%{_mandir}/man3/*%{ext_man}

%changelog
* Fri May 31 2019 pgajdos@suse.com
- enable the testsuite
- create netpbm-vulnerable subpackage and move pstopnm there
  [bsc#1139636]
* Thu May 16 2019 pgajdos@suse.com
- asan_build: build ASAN included
- debug_build: build more suitable for debugging
- security update
- added patches
  CVE-2017-2579 [bsc#1024288], CVE-2017-2580 [bsc#1024291]
  + netpbm-CVE-2017-2579,2580.patch
  neccessary for running with ASAN
  + netpbm-asan.patch
* Wed Jun 27 2018 pgajdos@suse.com
- security update
  * CVE-2018-8975 [bsc#1086777]
    + netpbm-CVE-2018-8975.patch
* Fri Dec 29 2017 tchvatal@suse.com
- Add patch makeman-py3.patch to make sure to use python3 when
  building
- Unpack the stuff only once
* Mon Dec 18 2017 pgajdos@suse.com
- updated to 10.80.1
  * pnmtopalm: Refuse to create a compressed image with more than 8
    bits per pixel.
  * pbmtext, libnetpbm font facilities: allow glyphs in font files
    that have no bitmap data; just used for their advance value to
    code a space.
  * pbmtext: Improve error message when there is a problem reading
    the font file.
  * libnetpbm font facilities: consider font invalid if a glyph is
    more than 65536 pixels high or wide.
  * ppmshadow: handle images with a black background and low
    contrast images (i.e. little difference between foreground and
    background).
  * ppmbrighten: fix bug: red pixels change hue.  Introduced in
    after Netpbm 10.11 (October 2002) and before Netpbm 10.18
    (September 2003).
  * palmtopnm: fix crash if invalid input contains color index that
    is not in the palette.  Always broken (palmtopnm was new in
    Netpbm 9.10 (October 2001)).
  * pnmtopalm: fix incorrect output with certain input files and
  - packbits_compression.  Always broken.  -packbits_compression
    was new in Netpbm 10.27 (March 2005).
  * pnmtopalm: Correct error message recommending running
    pnmquant when the real solution is to run pnmremap to modify the
    image to Palm standard colors.
  * pnmtopalm: Fix bug causing "color not in colormap" failure with
  - colormap and maxval other than 255.
  * libnetpbm: font facilities: fix invalid memory reference with
    certain font files.
  * libnetpbm: ppm_readcolordict: Improve error message when there is
    a problem reading the color dictionary.  Affects ppmhist.
  * pgmmake: Fix bug: treats non-numeric gray-level argument as zero.
    Always broken (Pgmmake was new in Netpbm 10.32, February 2006).
  * pdbimgtopam, pamtopdbimg: fix various cases of incorrect output,
    some always present (programs were new in Netpbm 10.52.00
    (October 2010)).
  * libnetpbm: pnm_parsecolorn(), pnm_parsecolor(): fix parsing of
    rgb: color specifications: yields value slightly too dim.
    Affects many programs.  Broken in Netpbm 10.79 (June 2017).
* Wed Aug  2 2017 tchvatal@suse.com
- Version update to 10.79.3:
  * Fix license clash between GPL-2 and GPL-3
  * Few small fixes
* Wed Jul 12 2017 tchvatal@suse.com
- Drop patch netpbm-missing-file-close.patch fixed differently by
  upstream
- Drop patch netpbm-jasper.patch which is no longer needed
- Remove accidental -O0 added to cflags
- Version update to 10.79.2:
  * Fix 'format-security' GNU compiler warning.
  * libnetpbm: pnm_parsecolorn(), pnm_parsecolor(): fix parsing of
    rgb: color specifications: yields value slightly too dim.
  * pamgauss: Add -maximize, -oversample .  Thanks Anton Shepelev
    <anton.txt@gmail.com>
  * pnmconvol: Extend -normalize to be applicable to convolution
    kernels specified by PGM file.  Thanks Anton Shepelev
    <anton.txt@gmail.com>
  * g3topbm: tolerate fill bits.
  * pbmtog3: Add -align8, -align16.
  * ppmshadow: Improve results for very small maxval.
  * ppmshadow: eliminate extraneous messages from pnmconvol.
  * libnetpbm: Improve error message for purported image that is
    exactly 1 byte long (so ends in the middle of what would be the
    magic number).
  * pbmtox10bm: Get the Perl interpreter for this Perl program from
    the PATH instead of hardcoded as /usr/bin/perl (like all other
    Netpbm Perl programs).
  * ppmcolormask: fix incorrect output when input maxval is not 255.
  * bmptopnm: fix crash when input is a Windows BMP with negative
    number for width.  Always broken.  (bmptopnm was new, as
    bmptoppm, in original Netpbm, 1992).
  * pamcomp: fix incorrect output with -mixtransparency.
    Always broken.  (-mixtransparency was new in Netpbm 10.56,
    September 2011).
  * pamcomp: remove debug trace message with -mixtransparency.
    Always broken.  (-mixtransparency was new in Netpbm 10.56,
    September 2011).
  * pnmtojpeg: fix array bounds violation in argument list.  Always
    broken (pnmtojpeg was new to Netpbm in Netpbm 8.2 (March 2000).
  * pamcrater: fix incorrect output with non-square image.
    Introduced in Netpbm 10.69 (December 2014).
  * svgtopam: fix treating negative width or height values in SVG
    like twos complement positive numbers; fail instead.  Always
    broken (svgtopam was new in Netpbm 10.33 (March 2006)).
  * svgtopam: fix error messages when input has splines or negative
    positions.  Always broken (svgtopam was new in Netpbm 10.33
    (March 2006)).
  * libnetpbm: fix bug: pm_system_XXX closes Standard Input if you
    supply a Standard Output accepter but not a Standard Input
    feeder.  Broken since Netpbm 10.40 (September 2007).
  * Build: don't try to build standardppmdfont.c if it already
    exists (so don't require ppmdcfont to exist).  Broken around
    Netpbm 10.35 (2006).
  * Build: Define _XOPEN_SOURCE=500 in source files that use M_PI.
    While C libraries in the past have always provided this with
    just _XOPEN_SOURCE=null, it appears that M_PI is actually
    defined by Single Unix Specification 2, aka UNIX98, for which
    you need _XOPEN_SOURCE=500, and Cygwin has changed to enforce
    this.
* Fri Jun  9 2017 pgajdos@suse.com
- updated to 10.78.5
  * pamgauss: Fix skewed output with even dimension.
  * bmptopnm: fix crash when input is a Windows BMP with negative
    number for width.
* Mon Jun  5 2017 pgajdos@suse.com
- updated to 10.78.4
  * pamcrater: fix incorrect output with non-square image.
  * libnetpbm: fix bug: pm_system_XXX closes Standard Input if you
    supply a Standard Output accepter but not a Standard Input
    feeder.
  * fix incorrect output with -mixtransparency.
  * pamcomp: remove debug trace message with -mixtransparency.
  * pnmtojpeg: fix array bounds violation in argument list.
  * ppmpat: Add -color.
  * ppmpat: Add -argyle1, -argyle2.
  * pnmtotiff: Fail with -miniswhite or -minisblack on color image
    rather than produce an invalid TIFF.
  * tifftopnmcmyk: Default rows per strip to the TIFF library
    default instead of whatever yields 8K strips.
  * tifftonm: Fix incorrect PBM output with two-color paletted TIFF
    image.
  * tifftopnm: Fix memory corruption when image is more pixels than
    can be represented as a C unsigned integer.
  * tifftopnmcmyk: Fix bug: fails with very wide images and no
  - rowsperstrip.
  * svgtopam: Fix crash when out of memory.
  * pnmcrop: Add -closeness
  * libnetpbm: ppmd_fill_path: remove debug trace.
  * pnmpad: Fix bug: incorrect output width.
- removed netpbm-no-build-date.patch: not needed since:
  * --version global option: with SOURCE_DATE_EPOCH environment
    variable, display source code datetime instead of build
    datetime.
* Tue Nov 22 2016 pgajdos@suse.com
- updated to 10.76.0
  * pnmquantall: Fix failure when temporary file location is
    not the same filesystem as the output file.
  * pnmquantall: Fix incorrect handling of when the Pnmremap or
    the final rename fails.
  * giftopnm: Fix bug: crash on little-endian computers that can't
    toleration unaligned memory access.  Thanks Ignatios Souvatzis
    (is@netbsd.org).  Broken in Netpbm 10.47 (June 2009).
  * cmuwmtopbm: fix trivial memory leak.  Always broken (cmuwmtopbm
    was in primordial Pbmplus, in 1988).
  * Build: tifftopnm.c: fix undefined WIFSIGNALED, etc.
* Tue Oct 25 2016 fstrba@suse.com
- Added patch:
  * netpbm-jasper.patch
    + Fix build with newer jasper
* Mon Aug 22 2016 pgajdos@suse.com
- updated to 10.75.1
  * see HISTORY for upstream changelog
  * refreshed, reduced, extended patches:
    netpbm-security-code.patch
    netpbm-security-scripts.patch
    netpbm-gcc-warnings.patch
* Thu Dec 17 2015 pgajdos@suse.com
- updated to 10.72.4
  * see HISTORY for upstrem changelog
  * added useful returns
    + netpbm-gcc-warnings.patch
  * forwardported
    . netpbm-security-code.patch
* Tue Jun 23 2015 mvyskocil@opensuse.org
- Drop all libp?m.so symlinks
* Mon May 11 2015 pgajdos@suse.com
- updated to 10.70.4
  * pambackground: fix bug: segfault or incorrect results in most
    cases.
  * ppmtoarbtxt: Fix some undefined behavior when program limits
    are exceeded.
  * anytopnm: convert all images in a multi-image GIF instead of
    just the first.
  * nmnorm: add -bsingle, -wsingle.
  * pamtosvg: fix use of unset variable; probably results in a
    crash.
  * pnmgamma -srgbtobt709, -bt709tosrgb: fix bug; incorrect output
    nearly always.
  * pamtilt: fix bug: unconditional crash.
  * pgmmorphconv: fix bug: always produces PGM Plain format.
  * giftopnm: Fix bug: crashes if purported GIF has neither a global
    color map nor a local one.
  * pgmmorphconv: add -gradient.
  * pnmhisteq: add -noblack and -nowhite.
  * tifftopnm: allow input file to be nonseekable.
  * Add yuy2topam.
  * Add pgmtosbig.
  * Add st4topgm, pgmtost4.
  * ppmtoarbtxt: fix bug: wrong output when high numbers represent
    darker.
  * ppmtorgb3: Fix buffer overflow with long input file name.
  * st4topgm: Fix bug: with no argument, uses file named "'" instead
    of Standard Input.
  * pnmconvol: Fix bug: wrong output for pixels that convolve to
    negative values (should be clipped to zero).
* Wed Nov 19 2014 pgajdos@suse.com
- updated to 10.68.1
  * pnmconvol: add -bias .
  * Remove pnmcomp, install a pnmcomp symlink for pamcomp.
  * Fix incorrect option parsing when there are multiple common
    options (e.g. -plain -quiet).
  * cameratopam: fix buffer overflow.
  * cameratopam: fix incorrect output.
  * ppmtopict: Fix unconditional crash.
* Mon Sep  8 2014 pgajdos@suse.com
- updated to 10.67.4
  * pcdovtoppm: Fix crash due to invalid operator == on some
    systems.
  * Fix incorrect option parsing when there are multiple common
    options (e.g. -plain -quiet).
  * sgitopnm: add ability to convert 2-channel SGI image.
    Thanks Prophet of the Way <afu@wta.att.ne.jp>.
  * etc. see HISTORY
- modified patches:
  * netpbm-make.patch (refreshed)
  * netpbm-security-code.patch (refreshed)
* Mon Sep  8 2014 crrodriguez@opensuse.org
- minor: man pages from section 3 are developer docs, move
  to -devel package
* Sat Aug 30 2014 coolo@suse.com
- fix license for spdx 1.2 (IJG is now part of it, loosing SUSE prefix)
* Mon Jun 23 2014 pgajdos@suse.com
- updated to 10.66.3
  * sgitopnm: fix bug: no output if input is RLE compressed.
  * jpegtopnm -dumpexif: fix incorrect display of resolution.
  * jpegtopnm -dumpexif: fix truncated make, model, or datetime.
  * jpegtopnm -dumpexif: fix wild pointer with invalid EXIF data.
  * build fixes
* Tue Apr  1 2014 pgajdos@suse.com
- updated to 10.66.00
  * Add pamvalidate.
  * Add pamfix: Does what pamfixtrunc did, plus repairs excessive
    sample values.
  * pgmramp: add -diagonal.
  * libnetpbm: Read functions validate that sample values do not
    exceed maxval.
  * etc. see HISTORY for details
* Wed Nov 27 2013 pgajdos@suse.com
- updated to 10.64.04
  * pnmtops: Fix bug: wrong output with -ascii85.  Introduced in
    10.63 (June 2013).
  * pnmtops: Fix bug: wrong output with -rle.  Introduced in
    10.63 (June 2013).
  * pnmtops: Fix bug: fails with message about waitpid() failing
    if invoked with SIGCHLD ignored.  Introduced in 10.56
    (September 2011).
  * pnmtops: Fix bug: closes Standard Error.  Introduced in
    10.64.02 (today).
  * pnmtops: Fix bug: program hangs if it inherits lots of open
    files.  Introduced in 10.56 (September 2011).
  * pngtopam: fix bug: ignores -gamma.  Introduced in 10.48
  * see HISTORY for details
- removed wordaccess-include-be.patch (upstreamed)
- removed stdbool-after-jasper.patch (workaround not needed yet)
* Thu Oct  3 2013 dvaleev@suse.com
- fix include syntax for BigEndian platforms
  (wordaccess-include-be.patch)
* Wed Sep 11 2013 pgajdos@suse.com
- updated to 10.63.01
  * pngtopam: fix bug: ignores -gamma.  Introduced in 10.48
    (September 2009).
  * Add pamtowinicon, winicontopam.  Thanks Ludolf Holzheid.
  * pgmnoise: add -maxval, speed up.  Thanks Prophet of the Way.
  * etc. see doc/HISTORY
- added stdbool-after-jasper.patch, to be removed in the next
  submission [bnc#839584]
* Mon Dec 31 2012 pgajdos@suse.com
- Update to 10.61.01:
  * pamstereogram: change -guidesize default from 10 to 20
  * pgmhist: Add -machine option.
  * pgmhist: Add -median, -quartile, and -decile options.
  * pamstereogram: Add -guidetop and -guidebottom options to replace
    trick where negative -guidesize means top, positive means
    bottom, absent means none.
  * pamstereogram: -smoothing smooths images even without -texfile.
  * pnmcat: set don't care bits in packed PBM output to zero so
    they are predictable.
  * etc. see doc/HISTORY
* Sun Dec  2 2012 asterios.dramis@gmail.com
- Update libmin to 60.
- Added libjpeg-devel, libxml2-devel and pkgconfig(x11) as build requirements.
* Wed Nov 21 2012 pgajdos@suse.com
- updated to 10.60.03:
  * Xbmtopbm: fix incorrect output, memory leak.  Thanks Prophet of
    the Way <afu@wta.att.ne.jp>.
  * Pamtojpeg2k: default to no compression ratio constraint and
    allow compression ratios less than 1.  Because of compression
    metadata, small images do require loss of quality in order to
    get down to a compression ratio of 1.
  * Sunicontopnm: Fix incorrect output for depth 8.  Always broken
    (depth = 8 capability was added in Netpbm 10.53 (December 2010).
    pamgauss: Fix bug: erroneously says -maxval is too big on 64 bit
    system.  Always broken (Pamgauss was added in 10.23 (July 2004).
  * xpmtoppm: major speedup for 3-character-per pixel files,
    memory reduction for all files: use hash table instead of
    linear search or direct index, go row by row.
  * xpmtoppm: fix bogus "color number too large" failure.  Broken
    in 10.49 (December 2009).
  * pnm_hashtuple: slight performance improvement from new hash
    function.  Thanks Prophet of the Way <afu@wta.att.ne.jp>.
  * ppmtospu: wild memory accesses.  Always broken (program added in
    10.58 (March 2012).
  * pamtosrf: fix storage corruption.  Always broken (program added
    in 10.55 (June 2011).
* Tue Nov 20 2012 pgajdos@suse.com
- add url tag
* Thu Sep  6 2012 pgajdos@suse.com
- updated to 10.59.2:
  * transition super-stable --> advanced branch
  * builds with libpng15
  * patches summary:
  - >  dropped unneeded or upstreamed patches:
  - fixes.patch
  - libpng14.patch
  - manpages.patch
  - pamscale.patch
  - pnmtopng-CAN-2978.patch
  - > left patches
    [#] make.patch (suse specific)
    [#] no-build-time.patch (suse specific)
    [#] missing-file-close.patch (should be upstreamed in newer
    versions)
    [#] tmpfile.patch (rewritten)
    [#] security-code.patch (taken from fedora, replacement of
    former security.patch)
    [#] security-scripts.patch (taken from fedora, replacement of
    former security2.patch)
* Thu Aug 30 2012 cfarrell@suse.com
- license update: BSD-3-Clause and GPL-2.0+ and SUSE-IJG and MIT and
  SUSE-Public-Domain
  SPDX format, as per Fedora declaration
* Tue Aug  7 2012 pgajdos@suse.com
- updated to 10.35.86:
  * ppmtobmp: fix failure with "internal error" message on all
    uses.
  * pamscale: fix all black output with resampling.
  * pgmtexture: fix integer overflow in difference variance.
  * pgmtexture: fix array bounds violations in various calculations.
  * pngtopnm: fix crash with invalid tIME chunk.
* Tue Nov  1 2011 pgajdos@suse.com
- updated to 10.35.82:
  * pnmtopng: fix bug: with -alpha specifying a mask which contains
    no fully transparent area, output PNG is fully opaque.
    Introduced in 10.29.
  * pnmquant: work with older Perl that doesn't have 3-argument open.
  * pnmtops: fix message: says "from top edge" where it means
    "from bottom edge."
  * pgmtexture: fix wrong sum variance result.  Wrong since the
    beginning.  Thanks Francois P. S. Luus <fpsluus@gmail.com>.
* Tue May 24 2011 pgajdos@novell.com
- updated to 10.35.80:
  * asciitopgm: fix bug: memory corruption on too-long lines.
  * asciitopgm: fix bug: improper handling of blank lines.
  * pngtopnm: fix bug: -verbose reports history chunk present when
    it's really a palette.
  * bmptopnm: Don't crash on invalid zero value of image height in
    the BMP header of a compressed file.
  * bmptopnm: don't crash on large invalid value of 'colorsused' in
    the BMP header.
  * ilbmtoppm: Don't crash on image that has a transparent color
    index, but no color map.
* Tue Nov 16 2010 pgajdos@suse.cz
- updated to 10.35.77:
  * ppmtompeg: fix crash with free of unallocated memory.
  * Build: don't expect snprintf() to exist.
  * Build: don't use <strings.h> or bzero().
* Wed Sep  1 2010 pgajdos@suse.cz
- updated to 10.35.76:
  * Pnmtopng:  -libversion doesn't report level of linked libz.
  * don't fail due to SIGRTMIN, SIGRTMAX being undefined.
  * palmtopnm: fix for pixel size 16.  Thanks Paul Bolle
    <pebolle@tiscali.nl>.
  * fix -reduce.  Introduced in 10.27.
- build against libpng14
  * libpng14.patch
* Tue Aug 31 2010 cristian.rodriguez@opensuse.org
- Do not include build date in binaries
* Tue Apr  6 2010 pgajdos@suse.cz
- requires libpng12-compat-devel instead of libpng-devel for build:
  netpbm will be compatible with libpng 1.4 branch from
  version 10.48
* Tue Mar 30 2010 pgajdos@suse.cz
- updated to 10.35.74 (see doc/HISTORY)
  * upstreamed or outdated
  - colornames-init.diff (present in the code)
  - endian.patch (tested against bnc#105431)
  - pamtouil.patch (present in the code)
  - ximtoppm-fixes.patch (present in the code)
  - [partially, refreshed] fixes.patch
  - pngtomng-transparent.patch (tested against bnc#225258)
  - rgb.patch (/usr/share/X11/rgb.txt is in RGB_DB2 yet)
  * .dif renamed to make.patch
  * gcc45.patch merged into fixes.patch
* Sat Feb 13 2010 rguenther@suse.de
- fix harmless buffer-overflow to fix build with GCC 4.5
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Nov 24 2009 pgajdos@suse.cz
- updated to 10.35.69 (see HISTORY)
* Thu Aug  6 2009 pgajdos@suse.cz
- updated to 10.35.66 (see HISTORY)
  + mainly build fixes
- added fclose [bnc#528306]
  * missing-file-close.patch
* Mon Jul 13 2009 coolo@novell.com
- fix broken symlink
* Wed Jun 17 2009 nadvornik@suse.cz
- improved generating of man pages [bnc#431226]
- fixed various warnings
* Tue Jun 16 2009 nadvornik@suse.cz
- generate man pages from html
* Mon Jun 15 2009 nadvornik@suse.cz
- updated to 10.35.64
  * for detailed changelog see
    /usr/share/doc/packages/netpbm/HISTORY
- use security patches from Fedora
* Mon Jun  1 2009 nadvornik@suse.cz
- build fix: use non-conflicting name instead of "getline"
* Wed Jan 14 2009 olh@suse.de
- obsolete libnetpbm-XXbit instead of netpbm-XXbit
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Nov 28 2008 nadvornik@suse.cz
- fixed a crash in pamperspective by an update to newer
  version [bnc#440954]
* Wed Oct 22 2008 nadvornik@suse.cz
- fixed "pamscale -reduce" [bnc#391972]
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Feb  1 2008 meissner@suse.de
- fixed potential 1 byte array overread
* Wed Nov 21 2007 nadvornik@suse.cz
- compile with -flax-vector-conversions
* Fri Nov  9 2007 nadvornik@suse.cz
- use system libjasper [#339731]
* Thu Jul 19 2007 nadvornik@suse.cz
- updated to 10.26.44 (many bugfixes)
- applied Shared Library Packaging Policy:
  * created libnetpbm-devel subpackage
  * renamed libnetpbm to libnetpbm10
* Wed Apr 11 2007 nadvornik@suse.cz
- removed ppmtompeg sources [#261140]
* Thu Mar 29 2007 rguenther@suse.de
- add flex BuildRequires
* Wed Dec  6 2006 prusnak@suse.cz
- fixed pamtouil crash when -name was specified (pamtouil.patch)
- changed transparency handling (pnmtopng-transparent.patch) [#225258]
* Thu Nov 30 2006 prusnak@suse.cz
- fixed missing manpages [#224478]
- fixed segfault in pbmtext [#224420]
* Tue Nov 14 2006 prusnak@suse.cz
- fixed [#216670]
  - removed man pages that pointed to online documentation (manpages.patch)
  - added man pages generated from HTML documentation (manpages.tar.bz2)
* Thu Mar 23 2006 nadvornik@suse.cz
- fixed uninitialized variables [#155948]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 nadvornik@suse.cz
- compile with -fstack-protector
* Thu Jan  5 2006 nadvornik@suse.cz
- updated to 10.26.22
* Tue Nov 15 2005 nadvornik@suse.cz
- fixed possible buffer overflow [#133649]
* Thu Oct 13 2005 nadvornik@suse.cz
- fixed possible buffer overflow (CAN-2005-2978) [#119601]
* Mon Sep 26 2005 nadvornik@suse.cz
- fixed fiasco on bigendian [#105431]
* Tue Aug  9 2005 nadvornik@suse.cz
- call ghostscript with the -dSAFER option [#102527]
* Mon Aug  1 2005 nadvornik@suse.cz
- fixed libnetpb.so symlink
* Fri Jul 29 2005 nadvornik@suse.cz
- installed palm colormaps required by plucker
* Thu Jul 28 2005 nadvornik@suse.cz
- updated to 10.26.12
* Wed Jun 22 2005 schwab@suse.de
- Fix aliasing bug.
- Don't strip binaries.
* Thu Jan  6 2005 nadvornik@suse.cz
- updated to 10.18.18
- fixed tempdir handling in anytopbm [#49446]
* Fri Nov 19 2004 ro@suse.de
- fixed file list
* Tue Aug 31 2004 jw@suse.de
- fix uninitialized colornames in libppmcolor.c,
  that caused ppmtoxpm to segv on x86-64.
* Fri Aug 27 2004 kukuk@suse.de
- Fix .so symlink
* Thu Aug 26 2004 nadvornik@suse.cz
- updated to 10.18.15: many bugfixes, incuding pnmtopng fix [#42868]
* Thu Mar 18 2004 nadvornik@suse.cz
- do not pack /usr/bin/doc.url [#36329]
* Fri Mar  5 2004 nadvornik@suse.cz
- fixed pbmtextps [#32104]
- fixed dangerous compiler warnings
* Mon Jan 26 2004 nadvornik@suse.cz
- fixed temp files handling [#34036]
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Thu Sep 18 2003 nadvornik@suse.cz
- fixed tail/head syntax [#31231]
* Wed May 28 2003 nadvornik@suse.cz
- remove unpackaged files from buildroot
* Thu Feb 13 2003 ro@suse.de
- fix symlink for libnetpbm.so
* Tue Feb 11 2003 nadvornik@suse.cz
- updated to 10.11.4
* Mon Aug  5 2002 nadvornik@suse.cz
- removed g3topbm again
* Mon Jul 29 2002 schwab@suse.de
- Fix reference to perl in scripts.
* Sat Jul 27 2002 kukuk@suse.de
- Create compatibility links for the old libraries to compile
  old sources
* Sat Jul 27 2002 meissner@suse.de
- %%_lib fixes, use RPM_OPT_FLAGS and -fPIC
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Fri Jul 26 2002 nadvornik@suse.cz
- updated to 10.5:
  - libraries libpbm, libpgm, libpnm, libppm merged to libnetpbm
  - documentation is in html only
* Tue May 14 2002 nadvornik@suse.cz
- fixed usage of the %%{_libdir} macro
* Tue Feb 26 2002 nadvornik@suse.cz
- fixed "#!/bin/sh" line in ppmtomap
* Thu Feb  7 2002 nadvornik@suse.cz
- updated to 9.24
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 10 2002 nadvornik@suse.cz
- update to 9.23:
  - bugfix release
- patched pnmtops to accept -dpi <number>x<number> [bug #12591]
- used macros %%{_lib} and %%{_libdir}
* Wed Dec  5 2001 nadvornik@suse.cz
- update to 9.21:
  - new: pamdeinterlace, pnmquant, ppmtoneo, neotoppm
* Tue Sep  4 2001 nadvornik@suse.cz
- removed jbigtopnm and pnmtojbig because of potential patent
  problems [bug #9903]
- fixed segfault in icontopnm
* Thu Aug 23 2001 ro@suse.de
- added pm.h and pm_config.h to INTERFACE_HEADERS
  (pm.h is included by pbm.h and includes pm_config.h)
* Thu Aug 23 2001 nadvornik@suse.cz
- update to 9.16
    new:   pbmtopsg3 (Postscript G3 fax), pbmtonokia, ppmrainbow
    pamoil (a replacement for pgmoil)
    fixes and updates:
    ppmtogif, ppmtojpeg, xpmtoppm, pnmtopng/pngtopnm,
    giftopnm, ppm3d, tifftopnm, pgmcrater, pnmgamma,
    ppmcie, pnmscale, pnmscalefixed, ppmtoeyuv, eyuvtoppm
    pstopnm
- removed hpcdtoppm from source, because selling and commercial
  using is prohibited
* Tue Jun  5 2001 pblaha@suse.cz
- upgrade on 9.14
- add documentation and examples for ppmtompeg fix bug #8647
* Thu Apr  5 2001 pblaha@suse.cz
- make ln -s pnmtoplainpnm  pnmnoraw and ln -s gemtopnm  gemtopbm
* Tue Apr  3 2001 kukuk@suse.de
- Remove g2topbm again due conficts with g3utils
* Mon Mar 26 2001 pblaha@suse.cz
- update on 9.12
* Wed Mar 14 2001 pblaha@suse.cz
-  remove g3topbm due to conflict with g3utils
* Wed Mar  7 2001 pblaha@suse.cz
- update on 9.11
* Wed Jan 24 2001 pblaha@suse.cz
- update on 9.10
* Thu Dec 21 2000 garloff@suse.de
- Add Provides + Obsoletes: libnetpb.
- Use some more macros in spec file.
- bzip2 source.
* Tue Dec  5 2000 schwab@suse.de
- Be sure to compile with -fpic.
* Mon Dec  4 2000 kukuk@suse.de
- Fix again path to perl
* Thu Nov 30 2000 pblaha@suse.cz
- remove g3topbm and pbmtog3 for conflict with g3utils
* Tue Nov 28 2000 kukuk@suse.de
- Use /usr/bin/perl
* Tue Nov 28 2000 pblaha@suse.cz
- remove hpcdtoppm because conflict with photocd
* Mon Oct  2 2000 pblaha@suse.cz
- update to 9.8 and rename libnetpb to libnetpbm
* Thu Sep 28 2000 ro@suse.de
- fixed Makefile deps
* Mon Jul 10 2000 bubnikv@suse.cz
- fixed pbmtog3 to use fixed width of fax image (standard), added
  switch to allow usage of source image width
- updated man page of pbmtog3
- changed URLs of home page and source file
* Tue Jun 20 2000 nadvornik@suse.cz
- added shhopt.h, libshhopt.*
* Fri May 26 2000 bubnikv@suse.cz
- sorted
* Fri May 19 2000 nadvornik@suse.cz
- fixed Imakefile
* Tue May 16 2000 nadvornik@suse.cz
- update to 8.4
- added BuildRoot
* Fri May 12 2000 schwab@suse.de
- pbmplus.h: fix linux configuration.
* Tue Feb 29 2000 kukuk@suse.de
- Let ldconfig create correct links for shared libraries and add
  them to file list
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jan 13 1999 ro@suse.de
- pbmplus.h: don't redeclare write on alpha
* Wed Jun 17 1998 ro@suse.de
- patched to build for libc5 and glibc
* Thu May 14 1998 ro@suse.de
- added patch to build pbmtosff from Christian Lademann
* Tue May 12 1998 ro@suse.de
- extracted package from libgr / build from own sources
